@@ -1,7 +1,8 @@
 #!/usr/bin/python
 
 import urllib2 as urllib
-from os import path
+from os import path, stat
+from datetime import datetime
 
 #URL = 'http://www.tfl.gov.uk/tfl/livetravelnews/realtime/by-date.aspx?offset=weekend'
 URL = 'http://www.tfl.gov.uk/tfl/livetravelnews/realtime/tube/default.html'
@@ -58,6 +59,13 @@ def parse_routeinfo(msg):
 				routes.append("%s,%s,bus" % (origin, destination))
 	return routes
 
+def old(fname):
+	today = datetime.now()
+	today = "%d%d%d" % (today.year, today.month, today.day)
+	filestamp = datetime.fromtimestamp(stat(fname).st_mtime)
+	filestamp = "%d%d%d" % (filestamp.year, filestamp.month, filestamp.day)
+	return today != filestamp
+
 def get_info(msg):
 	s = msg.split('>')
 	if len(s) >= 2:
@@ -142,7 +150,7 @@ def get(fname=OUTFILE):
 	if delays == "":
 		delays = ";"
 
-	if not path.exists(fname):
+	if (not path.exists(fname)) or old(fname):
 		try:
 			print "Writing file..."
 			f = open(fname, 'w')
