@@ -23,6 +23,8 @@ DATA_FILE = BASE_DIR + 'Tubes.dat'
 CLOSURES_FILE = BASE_DIR + 'Closures.txt'
 CONFIG_FILE = 'Config.txt'
 
+MAP_IMAGE = "tfl_map.png"
+
 CLOSURES_TIMEOUT = 300
 
 CHANGE_MARKER = "change"
@@ -438,7 +440,31 @@ def main():
 		from_entry.set_text(to_entry.get_text())
 		to_entry.set_text(tmp)
 
+	def togglemap(mapbuf, map_x, map_y):
+		win = hildon.StackableWindow()
+		win.set_title("Tube map")
+		win.fullscreen()
+		pannable_area = hildon.PannableArea()
+		pannable_area.set_property("mov-mode", hildon.MOVEMENT_MODE_BOTH)
+		image = gtk.Image()
+		image.set_from_pixbuf(mapbuf)
+		image_event = gtk.EventBox()
+		image_event.add(image)
+		image_event.connect("button_press_event", mapclick, pannable_area)
+		image_event.oldtime = 0
+		image_event.container = win
+		pannable_area.add_with_viewport(image_event)
+		win.add(pannable_area)
+		win.show_all()
+		pannable_area.jump_to(map_x, map_y)
+
+	def mapclick(widget, event, data):
+		if (event.time - widget.oldtime) < 250:
+			widget.container.destroy()
+		widget.oldtime = event.time
+
 	def showdialog(title, route):
+		hildon.hildon_gtk_window_set_progress_indicator(win, 1)
 		dialog = gtk.Dialog("Tube route", None, gtk.DIALOG_DESTROY_WITH_PARENT | gtk.DIALOG_NO_SEPARATOR)
 		dialog.add_button("Get route", gtk.RESPONSE_OK)
 		dialog.add_button("Cancel", -1)
@@ -470,7 +496,13 @@ def main():
 		dialog.destroy()
 		if (response == gtk.RESPONSE_OK) and (title.station_from != "") and (title.station_to != ""):
 			title.set_markup("<big>%s to %s</big>" % (Station[STATION_NAME][matchStation(title.station_from)], Station[STATION_NAME][matchStation(title.station_to)]))
-			route.set_markup(guide(title.station_from, title.station_to))
+			route.get_buffer().set_text(guide(title.station_from, title.station_to))
+			hildon.hildon_banner_show_information(win, 'qgn_note_infoprint', "Routing complete")
+		hildon.hildon_gtk_window_set_progress_indicator(win, 0)
+
+	mapbuf = gtk.gdk.pixbuf_new_from_file(MAP_IMAGE)
+	map_x = mapbuf.get_width()/2
+	map_y = mapbuf.get_height()/2
 
 	win = hildon.StackableWindow()
 	win.set_title("Tube route")
@@ -480,16 +512,20 @@ def main():
 	title.station_to = station_to
 	title.set_markup("<big>No route</big>")
 	vbox.pack_start(title, True, True, 5)
-	vbox.pack_start(gtk.Label(""), True, True, 5)
-	route = gtk.Label()
-	route.set_markup("")
-	route.set_line_wrap(True)
-	button = gtk.Button("New route")
-	button.connect("clicked", lambda button: showdialog(title, route))
+	route = hildon.TextView()
+	route.set_editable(False)
+	route.set_wrap_mode(gtk.WRAP_WORD)
+	routebutton = gtk.Button("New route")
+	routebutton.connect("clicked", lambda button: showdialog(title, route))
+	mapbutton = gtk.Button("Tube map (double-click to return)")
+	mapbutton.connect("clicked", lambda button: togglemap(mapbuf, map_x, map_y))
 	vbox.pack_start(route, True, True, 5)
 	vbox.pack_start(gtk.Label(""), True, True, 5)
-	vbox.pack_end(button, True, True, 5)
-	win.add(vbox)
+	vbox.pack_start(routebutton, True, True, 5)
+	vbox.pack_end(mapbutton, True, True, 5)
+	pannable_area = hildon.PannableArea()
+	pannable_area.add_with_viewport(vbox)
+	win.add(pannable_area)
 	win.connect("destroy", gtk.main_quit, None)
 	win.show_all()
 
